==> jc-1.4.0.tar.gz: soot/jimple/StringConstant.h <==
// public class soot.jimple.StringConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 51a35a83f0a4f8f1 soot_jimple_StringConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_jimple_StringConstant_H_
#define _JC_soot_jimple_StringConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_StringConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_StringConstant$sub_refs	_jc_soot_jimple_StringConstant$sub_refs;
typedef struct _jc_soot_jimple_StringConstant$sub_nonrefs	_jc_soot_jimple_StringConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_StringConstant$refs	_jc_soot_jimple_StringConstant$refs;
typedef struct _jc_soot_jimple_StringConstant$nonrefs	_jc_soot_jimple_StringConstant$nonrefs;
typedef struct _jc_soot_jimple_StringConstant$object	_jc_soot_jimple_StringConstant$object;

typedef const struct _jc_soot_jimple_StringConstant$vmethods	_jc_soot_jimple_StringConstant$vmethods;
typedef const struct _jc_soot_jimple_StringConstant$vtable	_jc_soot_jimple_StringConstant$vtable;
typedef const struct _jc_soot_jimple_StringConstant$vtype	_jc_soot_jimple_StringConstant$vtype;

// Constructors
extern void _jc_soot_jimple_StringConstant$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_jimple_StringConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_StringConstant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_StringConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
extern jint _jc_soot_jimple_StringConstant$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_StringConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_StringConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_StringConstant$object *_jc_soot_jimple_StringConstant$method$v$892cc6d83e64f7d5(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_jimple_StringConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
};

// Vtable
struct _jc_soot_jimple_StringConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_StringConstant$vmethods	soot_jimple_StringConstant;
};

// Vtype
struct _jc_soot_jimple_StringConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_StringConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_StringConstant$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_jimple_StringConstant$refs {
    _jc_soot_jimple_StringConstant$sub_refs	soot_jimple_StringConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_StringConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_StringConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_StringConstant$sub_nonrefs	soot_jimple_StringConstant;
};

// Object instance structure
struct _jc_soot_jimple_StringConstant$object {
	_jc_soot_jimple_StringConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_StringConstant$vtype	*vtype;
	_jc_soot_jimple_StringConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_StringConstant$vtype _jc_soot_jimple_StringConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_StringConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_StringConstant$class_object;

#endif	/* _JC_soot_jimple_StringConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/StringConstant.h <==
// public class soot.jimple.StringConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 51a35a83f0a4f8f1 soot_jimple_StringConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_jimple_StringConstant_H_
#define _JC_soot_jimple_StringConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_StringConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_StringConstant$sub_refs	_jc_soot_jimple_StringConstant$sub_refs;
typedef struct _jc_soot_jimple_StringConstant$sub_nonrefs	_jc_soot_jimple_StringConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_StringConstant$refs	_jc_soot_jimple_StringConstant$refs;
typedef struct _jc_soot_jimple_StringConstant$nonrefs	_jc_soot_jimple_StringConstant$nonrefs;
typedef struct _jc_soot_jimple_StringConstant$object	_jc_soot_jimple_StringConstant$object;

typedef const struct _jc_soot_jimple_StringConstant$vmethods	_jc_soot_jimple_StringConstant$vmethods;
typedef const struct _jc_soot_jimple_StringConstant$vtable	_jc_soot_jimple_StringConstant$vtable;
typedef const struct _jc_soot_jimple_StringConstant$vtype	_jc_soot_jimple_StringConstant$vtype;

// Constructors
extern void _jc_soot_jimple_StringConstant$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_StringConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_StringConstant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_StringConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_StringConstant$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_StringConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_StringConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_StringConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_StringConstant$object *_jc_soot_jimple_StringConstant$method$v$892cc6d83e64f7d5(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_StringConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_StringConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_StringConstant$vmethods	soot_jimple_StringConstant;
};

// Vtype
struct _jc_soot_jimple_StringConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_StringConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_StringConstant$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_jimple_StringConstant$refs {
    _jc_soot_jimple_StringConstant$sub_refs	soot_jimple_StringConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_StringConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_StringConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_StringConstant$sub_nonrefs	soot_jimple_StringConstant;
};

// Object instance structure
struct _jc_soot_jimple_StringConstant$object {
	_jc_soot_jimple_StringConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_StringConstant$vtype	*vtype;
	_jc_soot_jimple_StringConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_StringConstant$vtype _jc_soot_jimple_StringConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_StringConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_StringConstant$class_object;

#endif	/* _JC_soot_jimple_StringConstant_H_ */
